#
# spec file for package ghc-binary-search
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name binary-search
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.0.0.3
Release:        1.11
Summary:        Binary and exponential searches
License:        BSD-3-Clause
Group:          System/Libraries
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
# Begin cabal-rpm deps:
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hspec-devel
%endif
# End cabal-rpm deps

%description
__Introduction__

This package provides varieties of binary search functions. c.f.
"Numeric.Search" for the examples.

These search function can search for pure and monadic predicates, of type:

> pred :: Eq b => a -> b > pred :: (Eq b, Monad m) => a -> m b

The predicates must satisfy that the domain range for any codomain value is
continuous; that is, '∀x≦y≦z. pred x == pred z ⇒ pred y == pred x' .

For example, we can address the problem of finding the boundary of an
upward-closed set of integers, using a combination of exponential and binary
searches.

Variants are provided for searching within bounded and unbounded intervals of
both 'Integer' and bounded integral types.

The package was created by Ross Paterson, and extended by Takayuki Muranushi,
to be used together with SMT solvers.

__The Module Structure__

* "Numeric.Search" provides the generic search combinator, to search for pure
and monadic predicates. * "Numeric.Search.Bounded" , "Numeric.Search.Integer" ,
"Numeric.Search.Range" provides the various specialized searchers, which means
less number of function arguments, and easier to use.

<<https://travis-ci.org/nushio3/binary-search.svg?branch=master>>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%check
%if %{with tests}
%{cabal} test
%endif


%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.0.0.3 revision 0 with cabal2obs.
